*****
MOCPy
*****

MOCPy is a Python library allowing easy creation, parsing and manipulation of MOCs (Multi-Order Coverage maps). See the `documentation <https://mocpy.readthedocs.io/en/latest/>`__ for more details about installing MOCPy and using it.

|Travis Status| |Notebook Binder| |RTD|

.. |Travis Status| image:: http://img.shields.io/travis/cds-astro/mocpy.svg?branch=master
    :target: https://travis-ci.org/cds-astro/mocpy

.. |Notebook Binder| image:: http://mybinder.org/badge.svg
    :target: https://mybinder.org/v2/gh/cds-astro/mocpy/master

.. |RTD| image:: https://readthedocs.org/projects/mocpy/badge/?version=latest
    :target: https://mocpy.readthedocs.io/en/latest/?badge=latest
